==> aws-cdk.aws-dax-1.125.0.tar.gz: package/lib/dax-canned-metrics.generated.d.ts <==
export declare class DAXMetrics {
    static cpuUtilizationAverage(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static itemCacheHitsSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static itemCacheMissesSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static batchGetItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static batchWriteItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static cacheMemoryUtilizationAverage(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static clientConnectionsSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static deleteItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static errorRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static estimatedDbSizeAverage(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static evictedSizeSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static failedRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static faultRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static getItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static networkBytesInSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static networkBytesOutSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static networkPacketsInSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static networkPacketsOutSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static putItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static queryCacheHitsSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static queryCacheMissesSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static queryRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static scanCacheHitsSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static scanCacheMissesSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static scanRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static throttledRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static totalRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static transactGetItemsCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static transactWriteItemsCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
    static updateItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ClusterId: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-dax-1.133.0.tar.gz: package/lib/dax-canned-metrics.generated.d.ts <==
export declare class DAXMetrics {
    static cpuUtilizationAverage(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static itemCacheHitsSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static itemCacheMissesSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static batchGetItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static batchWriteItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static cacheMemoryUtilizationAverage(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static clientConnectionsSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static deleteItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static errorRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static estimatedDbSizeAverage(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static evictedSizeSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static failedRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static faultRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static getItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static networkBytesInSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static networkBytesOutSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static networkPacketsInSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static networkPacketsOutSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static putItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static queryCacheHitsSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static queryCacheMissesSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static queryRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static scanCacheHitsSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static scanCacheMissesSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static scanRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static throttledRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static totalRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static transactGetItemsCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static transactWriteItemsCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
    static updateItemRequestCountSum(dimensions: {
        ClusterId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ClusterId: string;
        };
        statistic: string;
    };
}
